@@ -13,12 +13,14 @@ package Lemonldap::NG::Manager;
 use 5.10.0;
 use utf8;
 use Mouse;
-our $VERSION = '1.9.8';
+our $VERSION = '1.9.9';
 use Lemonldap::NG::Common::Conf::Constants;
 use Lemonldap::NG::Common::PSGI::Constants;
 
 extends 'Lemonldap::NG::Manager::Lib', 'Lemonldap::NG::Handler::PSGI::Router';
 
+has csp => ( is => 'rw' );
+
 ## @method boolean init($args)
 # Launch initialization method
 #
@@ -70,6 +72,12 @@ sub init {
     return 0 unless (@working);
     $self->addRoute( links => 'links', ['GET'] );
 
+    my $portal = $Lemonldap::NG::Handler::Main::tsv->{portal}->();
+    $portal =~ s#https?://([^/]*).*#$1#;
+    $self->csp(
+"default-src 'self';frame-ancestors 'none';form-action 'self';img-src 'self' $portal;style-src 'self' $portal;"
+    );
+
     $self->defaultRoute( $working[0]->defaultRoute );
 
     my $linksIcons =
@@ -119,6 +127,17 @@ sub javascript {
         : '' );
 }
 
+sub sendHtml {
+    my ( $self, $req, $template, %args ) = @_;
+    my $res = $self->SUPER::sendHtml( $req, $template, %args );
+    push @{ $res->[1] },
+      'Content-Security-Policy' => $self->csp,
+      'X-Content-Type-Options'  => 'nosniff',
+      'X-Frame-Options'         => 'DENY',
+      'X-XSS-Protection'        => '1; mode=block';
+    return $res;
+}
+
 1;
 __END__
 
