@@ -6,7 +6,7 @@
 
 package Lemonldap::NG::Manager::Build::Attributes;
 
-our $VERSION = '1.9.6';
+our $VERSION = '1.9.7';
 use strict;
 use Regexp::Common qw/URI/;
 
@@ -25,6 +25,7 @@ my $perlExpr = sub {
     foreach my $f (@cf) {
         $s = "sub $f {1} $s";
     }
+    no warnings( 'redefine', 'uninitialized' );
     eval "$s $val";
     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
 };
@@ -287,6 +288,12 @@ sub attributes {
             type          => 'bool',
             documentation => 'Maintenance mode for all virtual hosts',
         },
+        nginxCustomHandlers => {
+            type    => 'keyTextContainer',
+            keyTest => qr/^\w+$/,
+            test    => qr/^[a-zA-Z][a-zA-Z0-9]*(?:::[a-zA-Z][a-zA-Z0-9]*)*$/,
+            msgFail => '__badPerlPackageName__',
+        },
         noAjaxHook => {
             default       => 0,
             type          => 'bool',
@@ -983,6 +990,7 @@ sub attributes {
                     foreach my $f (@cf) {
                         $s = "sub $f {1} $s";
                     }
+                    no warnings( 'redefine', 'uninitialized' );
                     eval $s;
                     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                 },
@@ -1016,6 +1024,7 @@ sub attributes {
                     foreach my $f (@cf) {
                         $s = "sub $f {1} $s";
                     }
+                    no warnings( 'redefine', 'uninitialized' );
                     eval $s;
                     return $@ ? ( 1, "__badExpression__: $@" ) : (1);
                   }
@@ -2423,8 +2432,9 @@ m{^(?:ldapi://[^/]*/?|\w[\w\-\.]*(?::\d{1,5})?|ldap(?:s|\+tls)?://\w[\w\-\.]*(?:
           { type => 'int', default => 3600 },
         oidcRPMetaDataOptionsAccessTokenExpiration =>
           { type => 'int', default => 3600 },
-        oidcRPMetaDataOptionsRedirectUris  => { type => 'text', },
-        oidcRPMetaDataOptionsExtraClaims   => { type => 'keyTextContainer', },
+        oidcRPMetaDataOptionsRedirectUris => { type => 'text', },
+        oidcRPMetaDataOptionsExtraClaims =>
+          { type => 'keyTextContainer', default => {} },
         oidcRPMetaDataOptionsBypassConsent => { type => 'bool', default => 0 },
 
     };
