@@ -181,7 +181,7 @@
       $scope.showModal('message.html');
     };
 
-    $scope.downloadConf = function(c, $scope) {
+    $scope.downloadConf = function() {
       window.open($scope.confPrefix + $scope.currentCfg.cfgNum + '?full');
     };
 
@@ -942,4 +942,4 @@
     };
   }]);
 
-})();
\ No newline at end of file
+})();
